package com.persagy.fm.sop.aop;

import com.persagy.common.aop.GlobalBussinessExceptionHandler;
import com.persagy.common.enums.ResponseCode;
import com.persagy.common.exception.BusinessException;
import com.persagy.common.utils.ResponseResult;
import com.persagy.fm.common.utils.FileUtil;
import com.persagy.fm.sop.constant.SopQueryConst;
import com.persagy.fm.sop.utils.OldResponseResultUtil;
import feign.FeignException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.converter.HttpMessageNotReadableException;
import org.springframework.validation.BindException;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.servlet.NoHandlerFoundException;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ValidationException;
import java.util.ArrayList;
import java.util.List;

/**
 * 全局异常拦截器
 * @author yuecaipu
 * @date 11:32 2020/12/1
 */
@Slf4j
@RestControllerAdvice
public class GlobalExceptionHandler extends GlobalBussinessExceptionHandler {
    @Override
    @ExceptionHandler({NullPointerException.class})
    public ResponseResult handleNullPointerException(NullPointerException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.B0001.getCode(), e.getMessage());
    }
    @Override
    @ExceptionHandler({BusinessException.class})
    public ResponseResult handleBusinessRuntimeException(BusinessException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(e.getErrorCode(), e.getErrorDesc(), e.getRespJson());
    }
    @Override
    @ExceptionHandler({MethodArgumentNotValidException.class})
    public ResponseResult handleMethodArgumentNotValidException(MethodArgumentNotValidException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.A0400.getCode(), e.getBindingResult().getFieldError().getDefaultMessage());
    }
    @Override
    @ExceptionHandler({BindException.class})
    public ResponseResult handleBindException(BindException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.A0400.getCode(), e.getBindingResult().getFieldError().getDefaultMessage());
    }
    @Override
    @ExceptionHandler({ValidationException.class})
    public ResponseResult handleValidationException(ValidationException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.A0400.getCode(), e.getCause().getMessage());
    }
    @Override
    @ExceptionHandler({IllegalArgumentException.class})
    public ResponseResult handleIllegalArgumentException(IllegalArgumentException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.A0400.getCode(), e.getMessage());
    }
    @Override
    @ResponseStatus(HttpStatus.NOT_FOUND)
    @ExceptionHandler({NoHandlerFoundException.class})
    public ResponseResult handleNoHandlerFoundException(NoHandlerFoundException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.A0422.getCode(), e.getMessage());
    }
    @Override
    @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
    @ExceptionHandler({FeignException.class})
    public ResponseResult handleFeignException(FeignException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.C0110.getCode(), e.getMessage());
    }
    @Override
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    @ExceptionHandler({HttpMessageNotReadableException.class})
    public ResponseResult handleHttpMessageNotReadableException(HttpMessageNotReadableException e) {
        log.error(e.getMessage(), e);
        return OldResponseResultUtil.errorResult(ResponseCode.A0402.getCode(), ResponseCode.A0402.getDesc());
    }
    @Override
    @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
    @ExceptionHandler({Exception.class})
    public ResponseResult handleException(Exception e) {
        log.error(e.getMessage(), e);
        // 针对请求地址为上传标准模板的特殊处理
        ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (null!=servletRequestAttributes){
            HttpServletRequest request = servletRequestAttributes.getRequest();
            String requestUri = request.getRequestURI();
            if (SopQueryConst.IMPORT_SOP_REQUEST_URI.equals(requestUri)){
                List<String> errorList = new ArrayList<>();
                errorList.add(e.getMessage());
                FileUtil.writeErrorContentToResponse(errorList,servletRequestAttributes.getResponse(),request, SopQueryConst.UPLOAD_SOP_ERR_FILE_NAME);
                return null;
            }
        }
        return OldResponseResultUtil.errorResult(ResponseCode.Z9999.getCode(), ResponseCode.Z9999.getDesc());
    }
}
