package com.persagy.fm.sop.controller;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.persagy.common.exception.BusinessException;
import com.persagy.fm.common.old.utils.StringUtil;
import com.persagy.fm.common.old.utils.ToolsUtil;
import com.persagy.fm.sop.annotations.JsonFieldFilter;
import com.persagy.fm.sop.entity.Sop;
import com.persagy.fm.sop.enums.MsgTypeEnum;
import com.persagy.fm.sop.model.dto.RefedSopBean;
import com.persagy.fm.sop.model.dto.SopBean;
import com.persagy.fm.sop.model.vo.*;
import com.persagy.fm.sop.service.IInstanceService;
import com.persagy.fm.sop.service.IProjectSopService;
import com.persagy.fm.sop.service.IWoFlowPlanService;
import com.persagy.fm.sop.utils.OldResponseResult;
import com.persagy.fm.sop.utils.OldResponseResultUtil;
import com.persagy.fm.sop.validator.ProjectEdit;
import com.persagy.fm.sop.validator.ProjectInsert;
import com.persagy.fm.sop.validator.ProjectQuery;
import com.persagy.fm.sop.validator.ProjectUpdate;
import com.persagy.old.common.*;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;

/***
 * Description: 项目SOP的controller类
 * @author : lijie
 * @date :2021/4/14 12:11
 * Update By lijie 2021/4/14 12:11
 */
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/restSopService")
@Api("项目SOP的接口")
public class SopController {
    private final IProjectSopService projectSopService;
    private final IInstanceService instanceService;
    private final IWoFlowPlanService woFlowPlanService;

    /***
     * Description: 根据sopId查询已发布的sop列表--后台使用 
     * @param queryPublishedSopVo : 查询参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/10 13:57
     * Update By lijie 2021/4/10 13:57
     */
    @ApiOperation(value = "根据sopId查询已发布的sop列表",hidden = true)
    @PostMapping("/queryPublishedSopListByIds")
    public OldResponseResult<SopBean> queryPublishedSopListByIds(@RequestBody @Validated QueryPublishedSopVo queryPublishedSopVo){
        return OldResponseResultUtil.successResult(projectSopService.queryPublishedSopListByIds(queryPublishedSopVo.getSopIds()));
    }

    /***
     * Description: 当对象名称变化或对象删除时更新sop
     * @param objectChangeVo : 请求参数
     * @author : lijie
     * @date :2021/4/10 14:34
     * Update By lijie 2021/4/10 14:34
     */
    @ApiOperation(value = "当对象名称变化或对象删除时更新sop",hidden = true)
    @PostMapping("/updateSopWhenObjectChange")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<Void> updateSopWhenObjectChange(@RequestBody ObjectChangeVo objectChangeVo) throws Exception {
        if (!MsgTypeEnum.TWO.getType().equals(objectChangeVo.getMsType())
              || !MsgTypeEnum.SEVEN.getType().equals(objectChangeVo.getMsType())){
            return OldResponseResultUtil.successResult(new ArrayList<>());
        }
        // 当对象名称变化或对象删除时更新sop
        projectSopService.updateSopWhenObjectChange(objectChangeVo,
                MsgTypeEnum.SEVEN.getType().equals(objectChangeVo.getMsType()));
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }

    /***
     * Description: 查询项目SOP列表
     * @param queryPublishedListVo : 请求参数
     * @return : com.persagy.fm.sop.utils.OldResponseResult<com.persagy.fm.sop.model.vo.PublishedListVo>
     * @author : lijie
     * @date :2021/4/10 17:57
     * Update By lijie 2021/4/10 17:57
     */
    @ApiOperation(value = "查询项目SOP列表")
    @PostMapping("/queryPublishedSopList")
    public OldResponseResult<PublishedListVo> queryPublishedSopList(@RequestBody @Validated(ProjectQuery.class) QueryPublishedListVo queryPublishedListVo) throws Exception{
        return OldResponseResultUtil.successResult(projectSopService.queryPublishedSopList(queryPublishedListVo));
    }

    /***
     * Description: 查询编辑中的sop列表 (只查询有效的，且已发布的sop)
     * @param queryPublishedListBaseVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/10 18:08
     * Update By lijie 2021/4/10 18:08
     */
    @ApiOperation(value = "查询编辑中的sop列表 ")
    @PostMapping("/queryEditingSopList")
    public OldResponseResult<SopBean> queryEditingSopList(@RequestBody @Validated(ProjectQuery.class) QueryPublishedListBaseVo queryPublishedListBaseVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.queryEditingSopList(queryPublishedListBaseVo));
    }

    /***
     * Description: 查询已作废的sop列表
     * @param queryPublishedListBaseVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/10 18:27
     * Update By lijie 2021/4/10 18:27
     */
    @ApiOperation(value = "查询编辑中的sop列表 ")
    @PostMapping("/queryDestroyedSopList")
    public OldResponseResult<SopBean> queryDestroyedSopList(@RequestBody @Validated(ProjectQuery.class) QueryPublishedListBaseVo queryPublishedListBaseVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.queryDestroyedSopList(queryPublishedListBaseVo));
    }

    /***
     * Description: 根据Id查询已发布的sop信息
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/10 18:47
     * Update By lijie 2021/4/10 18:47
     */
    @ApiOperation(value = "根据Id查询已发布的sop信息 ")
    @PostMapping("/queryPublishedSopById")
    public OldResponseResult<SopBean> queryPublishedSopById(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.queryPublishedSopById(querySopVo));
    }

    /***
     * Description: 根据Id查询可编辑的sop信息
     * @param querySopVo : 请求参数
     * @return : java.lang.String
     * @author : lijie
     * @date :2021/4/10 19:27
     * Update By lijie 2021/4/10 19:27
     */
    @ApiOperation(value = "根据Id查询可编辑的sop信息 ")
    @PostMapping("/querySopForEditById")
    public OldResponseResult<SopBean> querySopForEditById(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.querySopForEditById(querySopVo));
    }

    /***
     * Description: 作废sop信息
     * @param queryDestroySopVo : 请求参数
     * @return : java.lang.String
     * @author : lijie
     * @date :2021/4/13 9:07
     * Update By lijie 2021/4/13 9:07
     */
    @ApiOperation("作废sop信息")
    @PostMapping("/destroySopById")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<Void> destroySopById(@RequestBody QueryDestroySopVo queryDestroySopVo) throws Exception {
        projectSopService.destroySopById(queryDestroySopVo);
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }

    /***
     * Description: 恢复已作废的sop信息
     * @param queryDestroySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/13 16:12
     * Update By lijie 2021/4/13 16:12
     */
    @ApiOperation("恢复已作废的sop信息")
    @PostMapping("/recoverSopById")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<String> recoverSopById(@RequestBody QueryDestroySopVo queryDestroySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.recoverSopById(queryDestroySopVo));
    }

    /***
     * Description: 添加发布状态SOP
     * @param saveSopVo : 新建SOP的请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/13 20:32
     * Update By lijie 2021/4/13 20:32
     */
    @ApiOperation("添加发布状态SOP")
    @PostMapping("/addPublishedSop")
    public OldResponseResult<Void> addPublishedSop(@RequestBody SaveSopVo saveSopVo) throws Exception {
        projectSopService.addPublishedSop(saveSopVo);
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }
    
    /***
     * Description: 编辑sop时验证sop名称
     * @param queryVerifySopNameBaseVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/14 10:27
     * Update By lijie 2021/4/14 10:27
     */
    @ApiOperation("编辑sop时验证sop名称")
    @PostMapping("/verifySopNameForUpdate")
    public OldResponseResult<VerifySopNameVo> verifySopNameForUpdate(
            @RequestBody @Validated(ProjectUpdate.class) QueryVerifySopNameBaseVo queryVerifySopNameBaseVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.verifySopNameForUpdate(queryVerifySopNameBaseVo));
    }

    /***
     * Description: 添加SOP时验证sop名称
     * @param queryVerifySopNameBaseVo : 请求参数
     * @return : java.lang.String
     * @author : lijie
     * @date :2021/4/14 12:04
     * Update By lijie 2021/4/14 12:04
     */
    @ApiOperation("添加SOP时验证sop名称")
    @PostMapping("/verifySopNameForAdd")
    public OldResponseResult<VerifySopNameVo> verifySopNameForAdd(@RequestBody @Validated(ProjectInsert.class) QueryVerifySopNameBaseVo queryVerifySopNameBaseVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.verifySopNameForAdd(queryVerifySopNameBaseVo));
    }
    /***
     * Description: 添加草稿状态SOP
     * @param saveSopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/14 12:12
     * Update By lijie 2021/4/14 12:12
     */
    @ApiOperation("添加草稿状态SOP")
    @PostMapping("/addDraftSop")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<QuerySopVo> addDraftSop(@RequestBody @Validated(ProjectEdit.class) SaveSopVo saveSopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.addDraftSop(saveSopVo));
    }

    /***
     * Description: 发布sop
     * @param saveSopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/14 12:15
     * Update By lijie 2021/4/14 12:15
     */
    @ApiOperation("发布sop")
    @PostMapping("/publishSop")
    public OldResponseResult<QuerySopVo> publishSop(@RequestBody @Validated(ProjectUpdate.class) SaveSopVo saveSopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.publishSop(saveSopVo));
    }

    /***
     * Description: sop管理-编辑页-保存草稿状态sop
     * @param saveSopVo : 保存SOP的参数
     * @return : com.persagy.fm.sop.utils.OldResponseResult<com.persagy.fm.sop.model.vo.QuerySopVo>
     * @author : lijie
     * @date :2021/4/8 17:24
     * Update By lijie 2021/4/8 17:24
     */
    @ApiOperation("sop管理-编辑页-保存草稿状态sop")
    @Transactional(rollbackFor = BusinessException.class)
    @PostMapping("/saveDraftSop")
    public OldResponseResult<QuerySopVo> saveDraftSop(@RequestBody @Validated(ProjectUpdate.class) SaveSopVo saveSopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.saveDraftSop(saveSopVo));
    }

    /***
     * Description: sop管理-新增页-验证sop
     * @param saveSopVo : 请求参数
     * @return : java.lang.String
     * @author : lijie
     * @date :2021/4/2 15:28
     * Update By lijie 2021/4/2 15:28
     */
    @ApiOperation("sop管理-新增页-验证sop")
    @PostMapping("/verifySopBeforePublish")
    public OldResponseResult<String> verifySopBeforePublish(@RequestBody @Validated SaveSopVo saveSopVo) throws Exception{
        return OldResponseResultUtil.successResult(projectSopService.verifySopForPublish(saveSopVo));
    }

    /***
     * Description: 查询可供选择的sop，复制、引用时用
     * @param queryPublishedSelVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/19 9:16
     * Update By lijie 2021/4/19 9:16
     */
    @ApiOperation("查询可供选择的sop，复制、引用时用")
    @PostMapping("/querySopListForSel")
    public OldResponseResult<PublishedListVo> querySopListForSel(@RequestBody @Validated(ProjectQuery.class) QueryPublishedSelVo queryPublishedSelVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.querySopListForSel(queryPublishedSelVo));
    }

    /***
     * Description: 查询当前sop被引用的sop列表
     * @param queryReferencedSopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/19 11:41
     * Update By lijie 2021/4/19 11:41
     */
    @ApiOperation("查询当前sop被引用的sop列表")
    @PostMapping("/queryReferencedSopListById")
    public OldResponseResult<RefedSopBean> queryReferencedSopListById(@RequestBody @Validated QueryReferencedSopVo queryReferencedSopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.queryReferencedSopListById(queryReferencedSopVo));
    }

    /***
     * Description: 取消修订的sop信息
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/19 12:29
     * Update By lijie 2021/4/19 12:29
     */
    @ApiOperation("取消修订的sop信息")
    @PostMapping("/cancelReviseSopById")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<Void> cancelReviseSopById(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        projectSopService.cancelReviseSopById(querySopVo);
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }


    /***
     * Description: 删除草稿的sop信息
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/19 19:54
     * Update By lijie 2021/4/19 19:54
     */
    @PostMapping("/deleteDraftSopById")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<Void> deleteDraftSopById(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        projectSopService.deleteDraftSopById(querySopVo);
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }


    /***
     * Description: 编辑列表发布sop前验证
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/19 20:06
     * Update By lijie 2021/4/19 20:06
     */
    @PostMapping("/verifySopOnList")
    public OldResponseResult<String> verifySopOnList(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.verifySopOnList(querySopVo));
    }


    /***
     * Description: 发布sop信息
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/19 20:53
     * Update By lijie 2021/4/19 20:53
     */
    @PostMapping("/publishSopOnList")
    public OldResponseResult<QuerySopVo> publishSopOnList(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.publishSopOnList(querySopVo));
    }

	/***
	 * Description: 查询引用的sop作废的消息列表
	 * @param querySopVo : 请求参数
	 * @return : java.lang.String  
	 * @author : lijie
	 * @date :2021/4/19 21:03
	 * Update By lijie 2021/4/19 21:03
	 */
    @PostMapping("/querySopDestroyMsgList")
    public OldResponseResult<DestroyMsgVo> querySopDestroyMsgList(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.querySopDestroyMsgList(querySopVo));
    }

    /***
     * Description: 标记sop作废消息已读
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/19 21:55
     * Update By lijie 2021/4/19 21:55
     */
    @PostMapping("/markReadSopDestroyMsg")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<Void> markReadSopDestroyMsg(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        projectSopService.markReadSopDestroyMsg(querySopVo);
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }


    /***
     * Description: 查询待修订中的消息列表
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/20 11:22
     * Update By lijie 2021/4/20 11:22
     */
    @PostMapping("/querySopReviseMsgList")
    public OldResponseResult<ReviseMsgVo> querySopReviseMsgList(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.querySopReviseMsgList(querySopVo));
    }

    /***
     * Description: 忽略修订消息
     * @param queryReviseMsgVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/20 12:17
     * Update By lijie 2021/4/20 12:17
     */
    @ApiOperation("忽略修订消息")
    @PostMapping("/ignoreSopReviseMsg")
    @Transactional(rollbackFor = BusinessException.class)
    @ApiOperationSupport(ignoreParameters = {"revise_obj_id","reviseObjId"})
    public OldResponseResult<Void> ignoreSopReviseMsg(@RequestBody @Validated QueryReviseMsgVo queryReviseMsgVo) throws Exception {
        projectSopService.ignoreSopReviseMsg(queryReviseMsgVo);
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }

    /***
     * Description: 查询sop的历史版本列表
     * @param querySopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/20 14:06
     * Update By lijie 2021/4/20 14:06
     */
    @PostMapping("/querySopHisList")
    public OldResponseResult<SopHisListVo> querySopHisList(@RequestBody @Validated QuerySopVo querySopVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.querySopHisList(querySopVo));
    }

    /***
     * Description: 根据ID查询历史sop或者引用的sop详细信息
     * @param querySopDetailVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/20 14:46
     * Update By lijie 2021/4/20 14:46
     */
    @ApiOperation("根据ID查询历史sop或者引用的sop详细信息")
    @PostMapping("/querySopDetailById")
    public OldResponseResult<SopBean> querySopDetailById(@RequestBody @Validated QuerySopDetailVo querySopDetailVo) throws Exception {
        return OldResponseResultUtil.successResult(projectSopService.querySopDetailById(querySopDetailVo));
    }

    /***
     * Description: 查询自动修订方案
     * @param queryAutoReviseMsgVo :请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/20 18:52
     * Update By lijie 2021/4/20 18:52
     */
    @PostMapping("/queryAutoRevisePlan")
    public OldResponseResult<AutoReviseMsgVo> queryAutoRevisePlan(@RequestBody @Validated QueryAutoReviseMsgVo queryAutoReviseMsgVo) throws Exception {
          return OldResponseResultUtil.successResult(projectSopService.queryAutoRevisePlan(queryAutoReviseMsgVo));
    }

    /***
     * Description: 自动修订
     * @param autoReviseSopVo : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/20 21:10
     * Update By lijie 2021/4/20 21:10
     */
    @PostMapping("/autoReviseSop")
    @Transactional(rollbackFor = BusinessException.class)
    public OldResponseResult<Void> autoReviseSop(@RequestBody AutoReviseSopVo autoReviseSopVo) {
        if (StrUtil.isBlank(autoReviseSopVo.getUserId())
                || StrUtil.isBlank(autoReviseSopVo.getMsgId())
                || StrUtil.isBlank(autoReviseSopVo.getReviseObjId())
                || StrUtil.isBlank(autoReviseSopVo.getSopId())){
            throw new BusinessException("缺少必填项");
        }
        projectSopService.autoReviseSop(autoReviseSopVo);
        return OldResponseResultUtil.successResult(new ArrayList<>());
    }

    /***
     * Description: 实例化中间件
     * @param jsonObject : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/21 14:52
     * Update By lijie 2021/4/21 14:52
     */
    @PostMapping("/convertClassToObject")
    public String convertClassToObject(@RequestBody JSONObject jsonObject) throws Exception {
        if(!StringUtil.isNull(jsonObject, "project_id")){
            return instanceService.convertClassToObject(jsonObject);
        }
        return ToolsUtil.return_error_json;
    }

    /***
     * Description: 根据工单类型id作废sop与工单类型的关系
     * @param jsonObject : 
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/21 15:19
     * Update By lijie 2021/4/21 15:19
     */
    @PostMapping("/deleteSopOrderTypeRelByOrderTypeId")
    @Transactional(rollbackFor = BusinessException.class)
    public String deleteSopOrderTypeRelByOrderTypeId(@RequestBody JSONObject jsonObject) throws Exception {
        if(!StringUtil.isNull(jsonObject, "user_id","order_type_id")){
            return projectSopService.deleteSopOrderTypeRelByOrderType(jsonObject);
        }
        return ToolsUtil.return_error_json;
    }
    /***
     * Description: 组装工单令牌
     * @param jsonObject : 请求参数
     * @return : java.lang.String
     * @author : lijie
     * @date :2021/4/21 16:17
     * Update By lijie 2021/4/21 16:17
     */
    @PostMapping("/buildWorkOrder")
    public String buildWorkOrder(@RequestBody JSONObject jsonObject) throws Exception {
        return projectSopService.buildWorkOrder(jsonObject);
    }

	/***
	 * Description: 工单事项自动实例化
	 * @param jsonObject : 请求参数
	 * @return : java.lang.String  
	 * @author : lijie
	 * @date :2021/4/21 16:40
	 * Update By lijie 2021/4/21 16:40
	 */
    @PostMapping("/autoInstantiateWoMatters")
    public String autoInstantiateWoMatters(@RequestBody JSONObject jsonObject) throws Exception {
    	if (StringUtil.isNull(jsonObject, "user_id", "project_id") || StringUtil.isEmptyList(jsonObject, "published_matters")) {
    		return ToolsUtil.return_error_json;
    	}
    	return woFlowPlanService.autoInstantiateWoMatters(jsonObject);
    }
    /***
     * Description: 获得工单事项预览
     * @param jsonObject : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/21 16:47
     * Update By lijie 2021/4/21 16:47
     */
    @PostMapping("/getWoMattersPreview")
    public String getWoMattersPreview(@RequestBody JSONObject jsonObject) throws Exception {
        return projectSopService.getWoMattersPreview(jsonObject);
    }

    /***
     * Description: 我的工单-新增页:查询推荐的sop
     * @param jsonObject : 请求参数
     * @return : java.lang.String  
     * @author : lijie
     * @date :2021/4/21 16:59
     * Update By lijie 2021/4/21 16:59
     */
    @PostMapping("/queryRecommendSop")
    public String queryRecommendSop(@RequestBody JSONObject jsonObject) throws Exception {
    	return projectSopService.queryRecommendSop(jsonObject);
    }
    
}