package com.persagy.fm.sop.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.fm.common.constant.CommonConstant;
import com.persagy.fm.common.constant.enums.ResultEnum;
import com.persagy.fm.common.model.vo.GeneralDictVo;
import com.persagy.fm.common.old.utils.ToolsUtil;
import com.persagy.fm.sop.client.SaasClient;
import com.persagy.fm.sop.service.IGeneralDictService;
import com.persagy.old.common.JSONUtil;
import com.persagy.old.dao.DBCommonMethods;
import com.persagy.old.dao.DBConst;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

@Service
@RequiredArgsConstructor
public class GeneralDictServiceImpl implements IGeneralDictService {

    private final SaasClient saasClient;

    /***
     * Description: 根据字典类型查询字典数据
     * @param dictType :字典类型
     * @param srcProjectId :项目id
     * @return : java.util.List<com.persagy.fm.sop.model.vo.GeneralDictVo>
     * @author : lijie
     * @date :2021/4/9 16:17
     * Update By lijie 2021/4/9 16:17
     */
    @Override
    public List<GeneralDictVo> queryGeneralDictByKey(String dictType, String srcProjectId) {
        // 1.从saas服务查询符合条件的字典数据
        List<GeneralDictVo> generalDictVos = queryGeneralDictDataFromSaas(dictType);
        if (CollUtil.isEmpty(generalDictVos)){
            return new ArrayList<>();
        }
        // 2.处理自定义名称
        String projectId = StrUtil.blankToDefault(srcProjectId,"");
        for (GeneralDictVo generalDictVo : generalDictVos) {
            String customerName = generalDictVo.getCustomerName();
            if (StrUtil.isNotBlank(customerName) && customerName.startsWith("{")){
                String tempName = JSONObject.parseObject(customerName).getString(projectId);
                if (StrUtil.isNotBlank(tempName)){
                    generalDictVo.setName(tempName);
                }
            }
        }
        // 3.处理重复数据
        Set<String> codeNames = new HashSet<>();
        int size = generalDictVos.size();
        for (int i=size-1;i>=0;i--){
            GeneralDictVo generalDictVo = generalDictVos.get(i);
            String key = generalDictVo.getCode() + "-" + generalDictVo.getName();
            if (codeNames.contains(key)){
                generalDictVos.remove(i);
                continue;
            }
            codeNames.add(key);
        }
        // 4.根据项目和使用情况过滤
        List<GeneralDictVo> dictVos = generalDictVos.stream().filter(generalDictVo -> {
            // 1.根据自定义项目使用与否过滤
            if (StrUtil.isNotBlank(generalDictVo.getCustomerUse()) && generalDictVo.getCustomerUse().startsWith("{")) {
                Boolean proCustomerUse = JSONObject.parseObject(generalDictVo.getCustomerUse()).getBoolean(projectId);
                if (!proCustomerUse) {
                    return false;
                }
            }
            // 2.根据是否使用过滤
            return generalDictVo.getDefaultUse();
        }).collect(Collectors.toList());
        return dictVos.stream().sorted((o1,o2)->o2.getCode().compareTo(o1.getCode())).collect(Collectors.toList());
    }
    /***
     * Description: 查询工单类型列表
     * @param jsonObject : 请求参数
     * @return : java.lang.String
     * @author : lijie
     * @date :2021/4/19 12:16
     * Update By lijie 2021/4/19 12:16
     */
    @Override
    public String queryWoTypeList(JSONObject jsonObject){
        JSONObject params = new JSONObject();
        params.put(DBConst.TABLE_FIELD_VALID, true);
        // 状态：0-需维护，1-正常
        params.put("plan_status", "1");
        String parms = JSONUtil.getCriteriaWithMajors(params,"plan_status" ,DBConst.TABLE_FIELD_VALID).toJSONString();
        String resultStr = DBCommonMethods.queryRecordByCriteria(DBConst.DATABASE_WORK_ORDER, DBConst.TABLE_WO_FLOW_PLAN_PERSAGY, parms);
        JSONObject resultJson = JSONObject.parseObject(resultStr);
        if(DBConst.Result.FAILURE.equals(resultJson.getString(DBConst.Result.RESULT))){
            return resultStr;
        }
        JSONArray content = new JSONArray();
        JSONObject item;
        JSONArray woFlowPlans = resultJson.getJSONArray(DBConst.Result.CONTENT);
        woFlowPlans = woFlowPlans == null ? new JSONArray() : woFlowPlans;
        JSONObject woFlowPlan;
        for(int i=0; i<woFlowPlans.size(); i++){
            woFlowPlan = woFlowPlans.getJSONObject(i);
            item = new JSONObject();
            item.put("code", woFlowPlan.getString("plan_id"));
            item.put("name", woFlowPlan.getString("plan_name"));
            content.add(item);
        }
        return ToolsUtil.successJsonMsg(content);
    }

    /***
     * Description: 从saas服务查询数据字典数据
     * @param dictType : 字典类型
     * @return : java.util.List<com.persagy.fm.sop.model.vo.GeneralDictVo>  
     * @author : lijie
     * @date :2021/4/9 21:55
     * Update By lijie 2021/4/9 21:55
     */
    private List<GeneralDictVo> queryGeneralDictDataFromSaas(String dictType){
        JSONObject param = new JSONObject();
        param.put(CommonConstant.USER_ID, CommonConstant.SYSTEM_ID);
        param.put(CommonConstant.DICT_TYPE, dictType);
        String queryStr = saasClient.queryGeneralDictByDictType(param);
        JSONObject queryObj = JSONObject.parseObject(queryStr);
        if (ResultEnum.FAILURE.getType().equals(queryObj.getString(ResultEnum.RESULT.getType()))){
            return new ArrayList<>();
        }
        JSONArray content = queryObj.getJSONArray(ResultEnum.CONTENT.getType());
        if (null==content || content.size()<=0){
            return new ArrayList<>();
        }
        List<GeneralDictVo> generalDictVos = content.toJavaList(GeneralDictVo.class);
        if (CollUtil.isNotEmpty(generalDictVos)){
            generalDictVos = generalDictVos
                    .stream()
                    .sorted((d1,d2)->{
                        if (null==d1.getOrder()){
                            d1.setOrder(-1);
                        }
                        if (null==d2.getOrder()){
                            d2.setOrder(-1);
                        }
                        return d1.getOrder().compareTo(d2.getOrder());
                    })
                    .collect(Collectors.toList());
        }
        return generalDictVos;
    }



}
